############################################################################################################################### 
############################################################################################################################### 
############################################################################################################################### 
#########                                                                                                             #########
#########      Urbanization Predicts Flight Initiation Distance in Pigeons (Columba livia) Across New York City       #########
#########                                             Carlen, Li, and Winchell                                        #########
#########                                                                                                             #########
#########                                                                                                             #########
############################################################################################################################## 
############################################################################################################################### 
###############################################################################################################################

#basic packages for data handling and plots
library(ggplot2)
library(emmeans)
library(car)
library(Rmisc)
library(vegan)
library(dplyr)
library(standardize)
library(glmulti)

#alternate PCA
library(ggfortify)
library(FactoMineR)
library(factoextra)

#visualization packages
library(corrplot)  #for PCA loadings
library(ggthemes)
library(RColorBrewer)
library(patchwork)

#map plot
library(rgdal)
library(sf)
library(rgeos)
library(cluster)
library(mapdata)
library(ggmap)
library(sp)
library(ggspatial)

#for spatial autocorrelation tests
library(ncf)
library(nlme)
library(MuMIn)
library(reshape2)

#for path model
# view more info about this at https://rpubs.com/tbihansk/302732
library(lavaan)
library(semPlot)
library(OpenMx)
library(tidyverse)
library(knitr)
library(kableExtra)
library(GGally)


### Read in data:
pidgey <- read.csv("A21-00065R_data.csv")
names(pidgey)


#some of the GPS points are identical, for the spatial autocorrelation analysis this causes an error of "non-zero distances"
#we change the latitude of identical points by a small amount to address this error:

pidgey$locationUID <- as.factor(as.character(pidgey$locationUID))  #make location unique identifier a factor instead of an integet

dupeobs <- pidgey[duplicated(pidgey$locationUID)==TRUE,c("observation", "Lat_decimal", "Long_decimal", "locationUID")]  #identify records that are duplicate locations
pidgey$adj.lat <- pidgey$Lat_decimal #make new column for the adjusted latitude
dupelist <- rownames(dupeobs)  #get row numbers of the duplicate locations

#add 0.00001 to the latitude of any with just one duplicate, subtract 0.00001 from and that have 2 duplicates
pidgey[dupelist[-c(2,9,17)],c("adj.lat")] <- pidgey[dupelist[-c(2,9,17)],c("adj.lat")] + 0.00001
pidgey[dupelist[c(2,9,17)],c("adj.lat")] <- pidgey[dupelist[c(2,9,17)],c("adj.lat")]  - 0.00001

gcdist(x=c(pidgey$Long_decimal[1], pidgey$Long_decimal[1]), y=c(pidgey$adj.lat[1], pidgey$adj.lat[1]+0.00001))
#calculates the distance in km between points given decimal lat and long


################################################################################
###                   DETERMINE SIGNIFICANT COVARIATES                       ###
################################################################################

covarymod <- lm(FID_in_m ~  starting_distance2 + date.day + fractional_time + flock_size, pidgey)
summary(covarymod)  #since you have no categorical variables you can report the t-tests here for each variable instead of doing an ANOVA on the model (and the results should be identical)

#all 3 are significant


################################################################################
###                   CHECK FOR SPATIAL AUTOCORRELATION                      ###
################################################################################

#LISA - local indicator of spatial autocorrelation
FID.lisa <- lisa(pidgey$Long_decimal, pidgey$adj.lat, pidgey$FID_in_m, latlon=TRUE, neigh=0.001)
plot(FID.lisa)
#A bubble-plot of observations against spatial coordinates is produced. 
#Above mean values are signified by red circles. Below mean values are signified by black squares.
#Using a neighbor distance of 0.001 decimal degrees (very close) we find no evidence of local spatial autocorrelation - 

correlog.model.spline <- spline.correlog(x=pidgey$Long_decimal, y=pidgey$adj.lat, z=pidgey$FID_in_m, xmax = FALSE, latlon = TRUE, save=TRUE)   
plot(correlog.model.spline) # no pattern of decrease or increase means no spatial autocorrelation
mantel.model <- ncf::mantel.test(x=pidgey$Long_decimal, y=pidgey$adj.lat, z=pidgey$FID_in_m, resamp = 1000, latlon = TRUE, quiet = FALSE)
mantel.model 

#REPORT THESE VALUES IN RESULTS
#0 value = no correlation, -1 negative correlation, +1 positive correlation
#no spatial autocorrelation in FID data with spline correlog model


################################################################################
###                        Basic FID stats                                   ###
################################################################################

mean(pidgey$FID_in_m)
sd(pidgey$FID_in_m)
range(pidgey$FID_in_m)
pidgey$FID_in_m

################################################################################
###                        PCA of landscape variables                        ###
################################################################################

#drop NAs from included variables:
mydata_PCAvars <- na.omit(pidgey[,c( "percent_impervious", "mean_canopy_cover","developed_low_intensity", "developed_medium_intensity", 
                                     "developed_high_intensity", "open_space", "forest", "shrub_scrub_grassland", "water_wetlands","road_length")])

#PCA
landPCA <- prcomp(mydata_PCAvars, scale=T) 
summary(landPCA)  #report cumulative variance
biplot(landPCA)  #to visualize strength and direction of loadings

#get the eigenvalues
eigenvals(landPCA)  #retain any above 1, or broken stick (sudden drop off) -- use first four PCs for downstream analyses
get_eigenvalue(landPCA)  #does same thing as eigenvals and summary
fviz_eig(landPCA, addlabels = TRUE, ylim = c(0, 50))

#get the loadings for each PC 
landPCA$rotation
#PC1: (-) developed low intensity, open space (+) developed high intensity
#PC2: (-) impervious, road length, (+) canopy cover
#PC3: (-) forest,  open space, (+) developed medium intensity
#PC4: (-) forest, (+) shrub scrub, wetlands/water


#loadings plot:
corrplot(landPCA$rotation[,1:4], is.corr=FALSE)

# Contributions of variables to PC1
g1 <-fviz_contrib(landPCA, choice = "var", axes = 1, top = 10)
# Contributions of variables to PC2
g2 <-fviz_contrib(landPCA, choice = "var", axes = 2, top = 10)
# Contributions of variables to PC3
g3 <- fviz_contrib(landPCA, choice = "var", axes = 3, top = 10)
# Contributions of variables to PC4
g4 <- fviz_contrib(landPCA, choice = "var", axes = 4, top = 10)
# The total contribution to PC1, PC2, PC3, & PC4
g5 <-fviz_contrib(landPCA, choice = "var", axes = 1:4, top = 10) 

#stitch plots together
(g1 | g2 ) / (g3 | g4) / g5



#make DF with new PCs and all the variables that will be used
PCA.df <- data.frame(pidgey, landPCA$x)  #combine pc scores with full dataset


# visualize PCs by borough
fviz_pca_ind(landPCA,
             geom.ind = "point", # show points only (but not "text")
             col.ind = PCA.df$borough, # color by groups
             #palette = c("#00AFBB", "#E7B800", "#FC4E07"),
             addEllipses = TRUE, # Concentration ellipses
             legend.title = "Groups")

#alternatively:
ggplot(PCA.df, aes(x=PC1, y=PC2, colour=borough)) +stat_ellipse(geom="polygon",level=.95, alpha=.2,aes(fill=borough))  +stat_ellipse(level=.95)   + theme_bw() + geom_point() 

#or
autoplot(prcomp(landPCA$x), frame.type='norm', data=PCA.df, colour='borough') + ggtitle("PCA of Landscape Variables by Borough") + theme_bw()


#plot the PCs as boxplots to show that they differ by borough:
bp1 <- ggplot(PCA.df, aes(x=borough, y=PC1, fill=borough) ) + geom_boxplot() + theme_bw()
bp2 <- ggplot(PCA.df, aes(x=borough, y=PC2, fill=borough) ) + geom_boxplot() + theme_bw()
bp3 <- ggplot(PCA.df, aes(x=borough, y=PC3, fill=borough) ) + geom_boxplot() + theme_bw()
bp4 <- ggplot(PCA.df, aes(x=borough, y=PC4, fill=borough) ) + geom_boxplot() + theme_bw()

#stitch plots together
(bp1 | bp2) / (bp3 | bp4)


#Use MANOVA on all 4 of the PCs that are included:
PCman <- (manova(cbind(PC1, PC2, PC3, PC4) ~ borough, PCA.df, na.action=na.omit))
summary(PCman, test="Wilks")  #borough differs for at least one of the PCs
summary.aov(PCman) #ANOVA, all 4 PCs differ by borough. 



############################################################################################################################### 
#########                                                                                                             #########
#########                     Analysis #1:  Does FID differ across the metropolitan landscape                         #########
#########                                                                                                             #########
############################################################################################################################### 

#Variation in FID by borough?
modG2 <- lm(FID_in_m ~ borough + starting_distance2 + date.day + fractional_time, pidgey)
#summary(modG2)  
Anova(modG2)


bor.emm<-emmeans(modG2, c("borough"))
# pairwise contrasts:
contrast(bor.emm, "pairwise", simple = "each", combine = TRUE, adjust = "mvt") 
#investigate the difference in the means of each site type#
pwpp(bor.emm) 

#brooklyn and manhattan have the lowest FID, Staton island has highest FID, Bronx and Queens are intermediate
#staten island differs from every other borough

### verify spatial autocorrelation doesn't affect this models results
borough_mod <- lm(FID_in_m ~ borough  + starting_distance2 + date.day + fractional_time, pidgey)

##these compare different autocorrelation fits 
exp_auto_boroughmod <- gls(FID_in_m ~ borough  + starting_distance2 + date.day + fractional_time,
                           correlation = corExp(form = ~Long_decimal + adj.lat),  
                           data = pidgey, method="REML", na.action=na.omit)
gaus_auto_boroughmod <- gls(FID_in_m ~ borough  + starting_distance2 + date.day + fractional_time,
                            correlation = corGaus(form = ~Long_decimal + adj.lat),  
                            data = pidgey, method="REML", na.action=na.omit)
lin_auto_boroughmod <- gls(FID_in_m ~ borough  + starting_distance2 + date.day + fractional_time,
                           correlation = corLin(form = ~Long_decimal + adj.lat),  
                           data = pidgey, method="REML", na.action=na.omit)
sphere_auto_boroughmod <- gls(FID_in_m ~ borough  + starting_distance2 + date.day + fractional_time,
                              correlation = corSpher(form = ~Long_decimal + adj.lat),  
                              data = pidgey, method="REML", na.action=na.omit)
ratio_auto_boroughmod <- gls(FID_in_m ~ borough  + starting_distance2 + date.day + fractional_time,
                             correlation = corRatio(form = ~Long_decimal + adj.lat),  
                             data = pidgey, method="REML", na.action=na.omit)

#compare possible spatial autocorrelation models
model.sel(borough_mod, exp_auto_boroughmod, gaus_auto_boroughmod, lin_auto_boroughmod, sphere_auto_boroughmod,ratio_auto_boroughmod)
#original model not accounting for spatial autocorrelation has lowest AICc (highest weight) - this is the best model. 
#Spatial autocorrelation is not responsible for the patterns that we observed

#VISUALIZE: mean FID by borough
ggplot(pidgey, aes(x=borough, y=FID_in_m)) + 
  geom_boxplot() + 
  labs(x="borough", y="FID in meters") + 
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(), panel.background = element_blank(), axis.line = 
          element_line(colour = "black"))


#map FID by borough
#tutorial: http://zevross.com/blog/2014/07/16/mapping-in-r-using-the-ggplot2-package/
#tutorial: https://www.r-spatial.org/r/2018/10/25/ggplot2-sf.html
url <- "https://www1.nyc.gov/assets/planning/download/zip/data-maps/open-data/nybb_19d.zip"
fil <- basename(url)
if (!file.exists(fil)) download.file(url, fil)
fils <- unzip(fil)
nyc <- readOGR(fils[1], ogrListLayers(fils[1])[1], stringsAsFactors=FALSE)
nyc_map <- fortify(gSimplify(nyc, 0.05))
pidgey.map<-pidgey
coordinates(pidgey.map)<-~Long_decimal+Lat_decimal
proj4string(pidgey.map)<-CRS("+proj=longlat +datum=NAD83")
mapdata<-spTransform(pidgey.map,CRS(proj4string(nyc)))
mapdata<-data.frame(mapdata)
names(mapdata)[names(mapdata)=="longitude"]<-"x"
names(mapdata)[names(mapdata)=="latitude"]<-"y"

ggplot(mapdata, aes(y=Lat_decimal, x=Long_decimal, color=(log(FID_in_m))))  +
  geom_polygon(data=nyc, aes(x=long, y=lat, group=group), fill="grey40", colour="grey90", alpha=1)+
  geom_map(data=nyc, map=nyc_map,aes(x=long, y=lat, map_id=id), color="black", fill="white", size=0.25)+
  geom_point(data = mapdata, aes(y=Lat_decimal, x=Long_decimal,  position="jitter" , size=3)) +  
  coord_quickmap() +
  labs(x="Longitude", y="Latitude") +
  coord_equal(ratio=1)  + 
  scale_colour_gradientn(colours=rainbow(5,)) +
  annotation_scale() +
  annotation_north_arrow(which_north = "grid", style = north_arrow_fancy_orienteering) +
  theme(axis.text.x = element_blank(), axis.text.y = element_blank(),axis.ticks = element_blank()) 



############################################################################################################################### 
#########                                                                                                             #########
#########                     Analysis #2:  Does FID correlate with landscape features                                #########
#########                                                                                                             #########
############################################################################################################################### 

### run a step lm for FID with scaled variables 
full_model_PC_variables <- step(lm(FID_in_m ~  starting_distance2 + date.day + fractional_time +
                                     PC1 + PC2 + PC3 + PC4 +
                                     placemeter + population_size, data = PCA.df), direction="backward", trace = T, 
                               scope=list(lower= ~ starting_distance2 + date.day + fractional_time ))
summary(full_model_PC_variables)
plot(full_model_PC_variables)
hist(residuals(full_model_PC_variables))
mean(residuals(full_model_PC_variables))

drop1(full_model_PC_variables, test="F")

#Get the estimate of the model’s coefficient and the standard deviation for the model’s coefficient for each variable 
model_full_PC_variables <- lm(FID_in_m ~ 
                            starting_distance2 + 
                            date.day + 
                            fractional_time + 
                            PC1 + 
                            PC2 + 
                            PC3 + 
                            PC4 + 
                            placemeter + 
                            population_size, data = PCA.df)
summary(model_full_PC_variables)

model_reduced_PC_variables <- lm(FID_in_m ~ 
                            starting_distance2 + 
                            date.day + 
                            fractional_time + 
                            PC2 + 
                            PC3 + 
                            PC4 + 
                            placemeter + 
                            population_size, data = PCA.df)
summary(model_reduced_PC_variables)


#find the best models instead of doing a stepbackwards selection
landscape_models_glmulti<-glmulti(FID_in_m ~  
                                       starting_distance2 + 
                                       date.day + 
                                       fractional_time +
                                       PC1 + 
                                       PC2 + 
                                       PC3 + 
                                       PC4 +
                                       placemeter + 
                                       population_size, 
                                     data=PCA.df, level=1)
print(landscape_models_glmulti)

landscape_models_mumin<-lm(FID_in_m ~  
                                  starting_distance2 + 
                                  date.day + 
                                  fractional_time +
                                  PC1 + 
                                  PC2 + 
                                  PC3 + 
                                  PC4 +
                                  placemeter + 
                                  population_size, 
                                data=PCA.df, na.action = na.fail) 

landscape_models_mumin2<-dredge(landscape_models_mumin)
summary(landscape_models_mumin2)
summary(model.avg(landscape_models_mumin2))

######
### spatial autocorrelation?
#####
#verify spatial autocorrelation doesn't affect model results
landscape_mod <- lm(FID_in_m ~ starting_distance2 + date.day + fractional_time +
                      PC1 + PC2 + PC3 + PC4 +
                      placemeter + population_size, data = PCA.df)

##these compare different autocorrelation fits 
exp_auto_landmod <- gls(FID_in_m ~ starting_distance2 + date.day + fractional_time +
                          PC1 + PC2 + PC3 + PC4 +
                          placemeter + population_size,
                           correlation = corExp(form = ~Longitude + adj.lat),  
                           data = PCA.df, method="REML", na.action=na.omit)
gaus_auto_landmod <- gls(FID_in_m ~ starting_distance2 + date.day + fractional_time +
                           PC1 + PC2 + PC3 + PC4 +
                           placemeter + population_size,
                         correlation = corGaus(form = ~Long_decimal + adj.lat),  
                            data = PCA.df, method="REML", na.action=na.omit)
lin_auto_landmod <- gls(FID_in_m ~ starting_distance2 + date.day + fractional_time +
                          PC1 + PC2 + PC3 + PC4 +
                          placemeter + population_size,
                        correlation = corLin(form = ~Long_decimal + adj.lat),  
                           data = PCA.df, method="REML", na.action=na.omit)
sphere_auto_landmod <- gls(FID_in_m ~ starting_distance2 + date.day + fractional_time +
                             PC1 + PC2 + PC3 + PC4 +
                             placemeter + population_size,
                           correlation = corSpher(form = ~Long_decimal + adj.lat),  
                              data = PCA.df, method="REML", na.action=na.omit)
ratio_auto_landmod <- gls(FID_in_m ~ starting_distance2 + date.day + fractional_time +
                            PC1 + PC2 + PC3 + PC4 +
                            placemeter + population_size,
                          correlation = corRatio(form = ~Long_decimal + adj.lat),  
                             data = PCA.df, method="REML", na.action=na.omit)

#compare possible spatial autocorrelation models
model.sel(landscape_mod, exp_auto_landmod, gaus_auto_landmod, lin_auto_landmod, sphere_auto_landmod,ratio_auto_landmod)
#original model not accounting for spatial autocorrelation has lowest AICc (highest weight) - this is the best model. 
#Spatial autocorrelation is not responsible for the patterns that we observed



 

############################################################################################################################### 
#########                                                                                                             #########
#########                     Analysis #3:  Does FID  differ  with predator presence or abundance                     #########
#########                                                                                                             #########
############################################################################################################################### 

#do predator abundance or presence correlate with FID
#combine presence and abundance into a single model with model selection
predmod <- lm(FID_in_m ~  flock_size + 
                     coohwk_pres+rethaw_pres+perfal_pres +
                     cooper_hawks_all2017 +redtailed_hawks_all2017+peregrine_falcon_all2017+
                     starting_distance2 + date.day + fractional_time , pidgey)
summary(predmod)  #there are no categorical variables so you can use the model summary instead of Anova
predsimple <- (step(predmod))
summary(predsimple) #number of RT hawks and falcons influence FID (hawk +, falcon -), presence doesn't matter only abundance


#Get the estimate of the model’s coefficient and the standard deviation for the model’s coefficient for each variable 
model_full_predator_variables <- lm(FID_in_m ~ 
                                starting_distance2 + 
                                date.day + 
                                fractional_time + 
                                flock_size + 
                                coohwk_pres + 
                                rethaw_pres + 
                                perfal_pres + 
                                cooper_hawks_all2017 + 
                                redtailed_hawks_all2017 + 
                                peregrine_falcon_all2017, data = pidgey)
summary(model_full_predator_variables)

model_reduced_predator_variables <-lm(FID_in_m ~ 
                                        starting_distance2 + 
                                        date.day + 
                                        fractional_time + 
                                        redtailed_hawks_all2017 + 
                                        peregrine_falcon_all2017, data = pidgey)
summary(model_reduced_predator_variables)



#compare models instead of doing a stepbackwards selection
predator_models_comparison<-glmulti(FID_in_m ~ 
                                       starting_distance2 + 
                                       date.day + 
                                       fractional_time + 
                                       flock_size + 
                                       coohwk_pres + 
                                       rethaw_pres + 
                                       perfal_pres + 
                                       cooper_hawks_all2017 + 
                                       redtailed_hawks_all2017 + 
                                       peregrine_falcon_all2017, data = pidgey, level=1)
print(predator_models_comparison)


predator_models_mumin<-lm(FID_in_m ~ 
                            starting_distance2 + 
                            date.day + 
                            fractional_time + 
                            flock_size + 
                            coohwk_pres + 
                            rethaw_pres + 
                            perfal_pres + 
                            cooper_hawks_all2017 + 
                            redtailed_hawks_all2017 + 
                            peregrine_falcon_all2017, data = pidgey, na.action = na.fail) 

predator_models_mumin2<-dredge(predator_models_mumin)
get.models(predator_models_mumin2, subset=TRUE)
summary(model.avg(predator_models_mumin2))



######
### spatial autocorrelation?
#####
Predmod  <- lm(FID_in_m ~  redtailed_hawks_all2017 + peregrine_falcon_all2017 + 
                 starting_distance2 + date.day + fractional_time , pidgey)

##these compare different autocorrelation fits 
exp_auto_Predmod <- gls(FID_in_m ~ redtailed_hawks_all2017 + peregrine_falcon_all2017 + 
                          starting_distance2 + date.day + fractional_time ,
                          correlation = corExp(form = ~Long_decimal + adj.lat),  
                          data = pidgey, method="REML", na.action=na.omit)
gaus_auto_Predmod  <- gls(FID_in_m ~ redtailed_hawks_all2017 + peregrine_falcon_all2017 + 
                            starting_distance2 + date.day + fractional_time ,
                           correlation = corGaus(form = ~Long_decimal + adj.lat),  
                           data = pidgey, method="REML", na.action=na.omit)
lin_auto_Predmod <- gls(FID_in_m ~  redtailed_hawks_all2017 + peregrine_falcon_all2017 + 
                          starting_distance2 + date.day + fractional_time ,
                          correlation = corLin(form = ~Long_decimal + adj.lat),  
                          data = pidgey, method="REML", na.action=na.omit)
sphere_auto_Predmod <- gls(FID_in_m ~  redtailed_hawks_all2017 + peregrine_falcon_all2017 + 
                             starting_distance2 + date.day + fractional_time ,
                             correlation = corSpher(form = ~Long_decimal + adj.lat),  
                             data = pidgey, method="REML", na.action=na.omit)
ratio_auto_Predmod  <- gls(FID_in_m ~ redtailed_hawks_all2017 + peregrine_falcon_all2017 + 
                             starting_distance2 + date.day + fractional_time ,
                            correlation = corRatio(form = ~Long_decimal + adj.lat),  
                            data = pidgey, method="REML", na.action=na.omit)

#compare possible spatial autocorrelation models
model.sel(Predmod , exp_auto_Predmod , gaus_auto_Predmod , lin_auto_Predmod , sphere_auto_Predmod ,ratio_auto_Predmod )
#original model not accounting for spatial autocorrelation has lowest AICc (highest weight) - this is the best model. 
#Spatial autocorrelation is not responsible for the patterns that we observed

#full predator model for path analysis
predator_model_full<-'FID_in_m ~ starting_distance2 + date.day + fractional_time + flock_size + coohwk_pres + rethaw_pres + perfal_pres + cooper_hawks_all2017 + redtailed_hawks_all2017 + peregrine_falcon_all2017 + placemeter + population_size'
#fit the model
fit_full<-cfa(predator_model_full, data=pidgey)
#view the results
summary(fit_full, fit.measures = TRUE, standardized=T,rsquare=T)
#build a structural equation model (SEM)
semPaths(fit_full, 'std', layout = 'circle2', nCharNodes=0)

#reduced predator model for path analysis
predator_model_reduced<-'FID_in_m ~ redtailed_hawks_all2017 + peregrine_falcon_all2017 + starting_distance2'
#fit the model
fit_reduced<-cfa(predator_model_reduced, data=pidgey)
#view the results
summary(fit_reduced, fit.measures = TRUE, standardized=T,rsquare=T)
#build a structural equation model (SEM)
semPaths(fit_reduced, 'std', layout = 'circle2', nCharNodes=0)


#look for correlations between presence and abundance
cor.test(pidgey$perfal_pres, pidgey$peregrine_falcon_all2017)
cor.test(pidgey$coohwk_pres, pidgey$cooper_hawks_all2017)
cor.test(pidgey$rethaw_pres, pidgey$redtailed_hawks_all2017)


############################################################################################################################### 
#########                                                                                                             #########
#########                     Analysis #4:  Behavior before and after approach                                        #########
#########                                                                                                             #########
############################################################################################################################### 

respFID_behavior <- lm(FID_in_m ~  response2  + behavior2 +(distance_moved) + 
                         starting_distance2 + date.day + fractional_time , pidgey)
summary(respFID_behavior)
Anova(respFID_behavior, test="F")  

#group means for categorical variables
summarySE(pidgey,  measurevar= "FID_in_m", groupvars=c("behavior2"), na.rm=T)
summarySE(pidgey,  measurevar= "FID_in_m", groupvars=c("response2"), na.rm=T)
beh.emm<-emmeans(respFID_behavior, c("behavior2"))
# contrast(beh.emm, "pairwise", simple = "each", combine = TRUE, adjust = "mvt") #investigate the difference in the means of each site type#
pwpp(beh.emm)



######
### spatial autocorrelation?
#####
behmod <- lm(FID_in_m ~ response2  + behavior2 + (distance_moved) + 
                  starting_distance2 + date.day + fractional_time, pidgey)

##these compare different autocorrelation fits 
exp_auto_behmod <- gls(FID_in_m ~ response2  + behavior2  +(distance_moved) + 
                         starting_distance2 + date.day + fractional_time,
                         correlation = corExp(form = ~Long_decimal + adj.lat),  
                         data = pidgey, method="REML", na.action=na.omit)
gaus_auto_behmod <- gls(FID_in_m ~ response2  + behavior2  +(distance_moved) + 
                          starting_distance2 + date.day + fractional_time,
                          correlation = corGaus(form = ~Long_decimal + adj.lat),  
                          data = pidgey, method="REML", na.action=na.omit)
lin_auto_behmod <- gls(FID_in_m ~ response2  + behavior2  +(distance_moved) + 
                         starting_distance2 + date.day + fractional_time,
                         data = pidgey, method="REML", na.action=na.omit)
sphere_auto_behmod <- gls(FID_in_m ~ response2  + behavior2  +(distance_moved) + 
                            starting_distance2 + date.day + fractional_time,
                            correlation = corSpher(form = ~Long_decimal + adj.lat),  
                            data = pidgey, method="REML", na.action=na.omit)
ratio_auto_behmod <- gls(FID_in_m ~ response2  + behavior2  +(distance_moved) + 
                           starting_distance2 + date.day + fractional_time,
                           correlation = corRatio(form = ~Long_decimal + adj.lat),  
                           data = pidgey, method="REML", na.action=na.omit)

#compare possible spatial autocorrelation models
model.sel(behmod, exp_auto_behmod, gaus_auto_behmod, lin_auto_behmod, sphere_auto_behmod,ratio_auto_behmod)
#original model not accounting for spatial autocorrelation has lowest AICc (highest weight) - this is the best model. 
#Spatial autocorrelation is not responsible for the patterns that we observed

###
###
###


#did response type differ with predator abundance?
beh.res.mod <- glm(response2 ~ flock_size + 
                     coohwk_pres+rethaw_pres+perfal_pres +
                     cooper_hawks_all2017 +redtailed_hawks_all2017+peregrine_falcon_all2017, 
                   pidgey, na.action=na.omit, family="binomial")
summary(beh.res.mod)
summary(step(beh.res.mod))


#presence of coopers hawks alone influences escape response
pidgtemp <- pidgey[c("response2","coohwk_pres")]
pidgtempmelt <- melt(cbind(pidgtemp)) #these steps just manipulate the data into the format we need for the plot
write.csv(x=pidgtempmelt, "pidgtempmelt.csv")

ggplot(pidgtempmelt,aes(x = variable,fill = response2)) + 
  geom_bar(position = "fill") + theme_bw() + 
  scale_fill_manual(values=c("skyblue","forestgreen")) 
#slightly more likely to flee terrestrially when cooper hawks present


#did FID differe with predator abundance?
FID.res.mod <- lm(FID_in_m ~ flock_size + 
                     coohwk_pres+rethaw_pres+perfal_pres +
                   pidgey, na.action=na.omit, family="binomial")
summary(FID.res.mod)
summary(step(FID.res.mod))



#Visualizations
ggplot(pidgey, aes(x=response2, y=FID_in_m)) + geom_boxplot() #aerial flee more readily
# ggplot(pidgey, aes(x=response2, y=residFID)) + geom_boxplot()
ggplot(pidgey, aes(x=behavior2, y=FID_in_m)) + geom_boxplot() #statoinary flee less readily
ggplot(pidgey, aes(x=log(distance_moved), y=FID_in_m)) + geom_point() + geom_smooth(method="lm")

#plotting FID responses against predator sightings
ggplot(pidgey, aes(x=log(peregrine_falcon_all2017+1), y=FID_in_m)) + geom_point() + geom_smooth(method="lm")
ggplot(pidgey, aes(x=log(cooper_hawks_all2017+1), y=FID_in_m)) + geom_point() + geom_smooth(method="lm")
ggplot(pidgey, aes(x=log(redtailed_hawks_all2017+1), y=FID_in_m)) + geom_point() + geom_smooth(method="lm")



#create a box plot to show FID in relation to predator presence/absence
p1 <- ggplot(pidgey, aes(x=perfal_pres, y=FID_in_m, fill=as.factor(perfal_pres))) + 
  geom_boxplot() +
  theme(legend.position = "none", axis.text.x = element_blank(),  axis.ticks.x = element_blank()) +
  labs (x = "Peregrine Falcon", y= "FID (in m)") +
  scale_fill_manual(values=c("white", "snow4"))


p2 <- ggplot(pidgey, aes(x=coohwk_pres, y=FID_in_m, fill=as.factor(coohwk_pres)))  + 
  geom_boxplot() + 
  theme(legend.position = "none", axis.title.y = element_blank(),  axis.text.x = element_blank(),axis.text.y = element_blank(), axis.ticks = element_blank()) +
  labs (x = "Cooper's Hawk") +
  scale_fill_manual(values=c("white", "snow4"))

p3 <- ggplot(pidgey, aes(x=rethaw_pres, y=FID_in_m, fill=as.factor(rethaw_pres)))  + 
  geom_boxplot() + 
  theme(axis.title.y = element_blank(),  axis.text.x = element_blank(),axis.text.y = element_blank(),  axis.ticks = element_blank()) +
  labs(x = "Red-tailed Hawk", fill = "predator presence") +
  scale_fill_manual(values=c("white", "snow4"))

theme_set(theme_bw())

(p1 + p2 + p3) + annotate("text", x=c(1,2,3), y=rep(3,3),label= c("*","**","*"),size=5)



############################################################################################################################### 
#########                                                                                                             #########
#########                     Plot:  scatter plots & maps of pedestrian density, population density, &                #########
#########                                                impervious surface (Fig 3)                                   #########
#########                                                                                                             #########
############################################################################################################################### 


pidgey.plots<-PCA.df[,c("observation", "date.day", "fractional_time", "weather",
                        "temp", "Lat_decimal", "Long_decimal",
                        "flock_resample", "borough",
                        "flock_size", "behavior",
                        "starting_distance", "response", "distance_moved", "FID_in_m",
                        "percent_impervious","placemeter", "population_size", "noise_complaints",
                        "Notes","date.day", "cooper_hawks_all2017",  "peregrine_falcon_all2017", "redtailed_hawks_all2017", 
                        "mean_canopy_cover", "developed_low_intensity", "developed_medium_intensity", "developed_high_intensity", "open_space",
                        "forest", "shrub_scrub_grassland", "water_wetlands", "road_length", "locationUID" ,
                        "PC1", "PC2", "PC3", "PC4",
                        "Latitude", "Longitude")]


#plot FID as a function of population size; colored by point
sp_pop <- ggplot(pidgey.plots, aes(population_size, FID_in_m, color = population_size)) +
  geom_point() +
  stat_smooth(aes(group = 1), method = "lm", se = FALSE, color = "black") +
  scale_color_distiller(palette = "Purples", direction = 1) +
  theme_classic() +
  theme(legend.position = "none") +
  labs(x = "Population Size", y = "FID (m)") + 
  stat_smooth(aes(group = 1), method = "lm", formula = y ~ x, se = FALSE, color="black")
population_size_plot<- lm(FID_in_m~population_size, data=pidgey.plots)
summary(population_size_plot)
sp_pop

#plot FID as a function of pedestrian; colored by point
sp_ped <- ggplot(pidgey.plots, aes(placemeter, FID_in_m, color = placemeter)) +
  geom_point() +
  stat_smooth(aes(group = 1), method = "lm", se = FALSE, color = "black") +
  scale_color_distiller(palette = "Greens", direction = 1) +
  theme_classic() +
  theme(legend.position = "none") +
  labs(x = "Pedestrian Density", y = "FID (m)") + 
  stat_smooth(aes(group = 1), method = "lm", formula = y ~ x, se = FALSE, color="black")
placemeter_plot<- lm(FID_in_m~placemeter, data=pidgey.plots)
summary(placemeter_plot)
sp_ped

#plot FID as a function of PC2; colored by point
sp_PC2 <- ggplot(pidgey.plots, aes(PC2, FID_in_m, color = PC2)) +
  geom_point() +
  stat_smooth(aes(group = 1), method = "lm", se = FALSE, color = "black") +
  scale_color_distiller(palette = "Blues", direction = 1) +
  theme_classic() +
  theme(legend.position = "none") +
  labs(x = "PC2", y = "FID (m)") + 
  stat_smooth(aes(group = 1), method = "lm", formula = y ~ x, se = FALSE, color="black")
PC2_plot<- lm(FID_in_m~PC2, data=pidgey.plots)
summary(PC2_plot)
sp_PC2

#make a map of pop density
map_pop <- ggplot(mapdata, aes(y=Lat_decimal, x=Long_decimal, color=(population_size)))  +
  geom_polygon(data=nyc, aes(x=long, y=lat, group=group), fill="grey40", colour="grey90", alpha=1)+
  geom_map(data=nyc, map=nyc_map,aes(x=long, y=lat, map_id=id), color="black", fill="white", size=0.25)+
  geom_point(data = mapdata, aes(y=Lat_decimal, x=Long_decimal ), cex=0.5) +  
  coord_quickmap() +
  labs(x="Longitude", y="Latitude") +
  coord_equal(ratio=1)  + 
  scale_color_distiller(palette="Purples", direction = 1) +
  theme(axis.text.x = element_blank(), axis.text.y = element_blank(),axis.ticks = element_blank(), legend.position = c(0.2, 0.8), panel.grid = element_blank())
map_pop

#make a map of pedestrian density
map_ped <- ggplot(pidgey.plots, aes(y=Lat_decimal, x=Long_decimal, color=(placemeter)))  +
  geom_polygon(data=nyc, aes(x=long, y=lat, group=group), fill="grey40", colour="grey90", alpha=1)+
  geom_map(data=nyc, map=nyc_map,aes(x=long, y=lat, map_id=id), color="black", fill="white", size=0.25)+
  geom_point(data = mapdata, aes(y=Lat_decimal, x=Long_decimal ), cex=0.5) +  
  coord_quickmap() +
  labs(x="Longitude", y="Latitude") +
  coord_equal(ratio=1)  + 
  scale_color_distiller(palette="Greens", direction = 1) +
  theme(axis.text.x = element_blank(), axis.text.y = element_blank(),axis.ticks = element_blank(), legend.position = c(0.2, 0.8), panel.grid = element_blank())
map_ped

#make a map of PC2
pidgey.plots.rounded<-pidgey.plots %>%mutate_at(vars(starts_with("PC2")), funs(round(., 0)))
pidgey.plotsPC_mapdata <-left_join(mapdata,pidgey.plots.rounded,by="observation")
map_PC2 <-ggplot(pidgey.plotsPC_mapdata, aes(y=Lat_decimal.x, x=Long_decimal.x,color = PC2)) +
  geom_polygon(data=nyc, aes(x=long, y=lat, group=group), fill="grey40",colour="grey90", alpha=1)+
  geom_map(data=nyc, map=nyc_map,aes(x=long, y=lat, map_id=id),color="black", fill="white", size=0.25)+
  geom_point(cex=0.5) +
  coord_quickmap() +
  labs(x="Longitude", y="Latitude") +
  coord_equal(ratio=1)  +
  scale_color_distiller(palette="Blues", direction=1) +
  theme(axis.text.x = element_blank(), axis.text.y = element_blank(),axis.ticks = element_blank(), legend.position = c(0.2, 0.8), panel.grid = element_blank())
map_PC2





############################################################################################################################### 
#########                                                                                                             #########
#########                     Plot:  scatter plots & maps of predators                                                #########
#########                                                                                                             #########
#########                                                                                                             #########
############################################################################################################################### 

#plot FID as a function of RTHA; colored by point
sp_RTHA <- ggplot(pidgey.plots, aes(redtailed_hawks_all2017, FID_in_m, color = redtailed_hawks_all2017)) +
  geom_point() +
  stat_smooth(aes(group = 1), method = "lm", se = FALSE, color = "black") +
  scale_color_distiller(palette = "RdBu", direction = 1) +
  theme_classic() +
  theme(legend.position = "none") +
  labs(x = "redtailed_hawks_all2017", y = "FID (m)") + 
  stat_smooth(aes(group = 1), method = "lm", formula = y ~ x, se = FALSE, color="black")
RTHA_plot<- lm(FID_in_m~redtailed_hawks_all2017, data=pidgey.plots)
summary(RTHA_plot)
sp_RTHA

#plot FID as a function of COHA; colored by point
sp_COHA <- ggplot(pidgey.plots, aes(cooper_hawks_all2017, FID_in_m, color = cooper_hawks_all2017)) +
  geom_point() +
  stat_smooth(aes(group = 1), method = "lm", se = FALSE, color = "black") +
  scale_color_distiller(palette = "PuOr", direction = 1) +
  theme_classic() +
  theme(legend.position = "none") +
  labs(x = "cooper_hawks_all2017", y = "FID (m)") + 
  stat_smooth(aes(group = 1), method = "lm", formula = y ~ x, se = FALSE, color="black")
COHA_plot<- lm(FID_in_m~cooper_hawks_all2017, data=pidgey.plots)
summary(COHA_plot)
sp_COHA


#plot FID as a function of PEFA; colored by point
sp_PEFA <- ggplot(pidgey.plots, aes(peregrine_falcon_all2017, FID_in_m, color = peregrine_falcon_all2017)) +
  geom_point() +
  stat_smooth(aes(group = 1), method = "lm", se = FALSE, color = "black") +
  scale_color_distiller(palette = "BrBG", direction = -1) +
  theme_classic() +
  theme(legend.position = "none") +
  labs(x = "peregrine_falcon_all2017", y = "FID (m)") + 
  stat_smooth(aes(group = 1), method = "lm", formula = y ~ x, se = FALSE, color="black")
PEFA_plot<- lm(FID_in_m~peregrine_falcon_all2017, data=pidgey.plots)
summary(PEFA_plot)
sp_PEFA


#make a map of Red-tailed Hawks
map_RTHA <- ggplot(mapdata, aes(y=Lat_decimal, x=Long_decimal, color=(redtailed_hawks_all2017)))  +
  geom_polygon(data=nyc, aes(x=long, y=lat, group=group), fill="grey40", colour="grey90", alpha=1)+
  geom_map(data=nyc, map=nyc_map,aes(x=long, y=lat, map_id=id), color="black", fill="white", size=0.25)+
  geom_point(data = mapdata, aes(y=Lat_decimal, x=Long_decimal ), cex=0.5) +  
  coord_quickmap() +
  labs(x="Longitude", y="Latitude") +
  coord_equal(ratio=1)  + 
  scale_color_distiller(palette="RdBu", direction = 1) +
  theme(axis.text.x = element_blank(), axis.text.y = element_blank(),axis.ticks = element_blank(), legend.position = c(0.2, 0.8), panel.grid = element_blank())
map_RTHA

#make a map of Cooper's Hawks
map_COHA <- ggplot(mapdata, aes(y=Lat_decimal, x=Long_decimal, color=(cooper_hawks_all2017)))  +
  geom_polygon(data=nyc, aes(x=long, y=lat, group=group), fill="grey40", colour="grey90", alpha=1)+
  geom_map(data=nyc, map=nyc_map,aes(x=long, y=lat, map_id=id), color="black", fill="white", size=0.25)+
  geom_point(data = mapdata, aes(y=Lat_decimal, x=Long_decimal ), cex=0.5) +  
  coord_quickmap() +
  labs(x="Longitude", y="Latitude") +
  coord_equal(ratio=1)  + 
  scale_color_distiller(palette="PuOr", direction = 1) +
  theme(axis.text.x = element_blank(), axis.text.y = element_blank(),axis.ticks = element_blank(), legend.position = c(0.2, 0.8), panel.grid = element_blank())
map_COHA

#make a map of Peregrine Falcons
map_PEFA <- ggplot(mapdata, aes(y=Lat_decimal, x=Long_decimal, color=(peregrine_falcon_all2017)))  +
  geom_polygon(data=nyc, aes(x=long, y=lat, group=group), fill="grey40", colour="grey90", alpha=1)+
  geom_map(data=nyc, map=nyc_map,aes(x=long, y=lat, map_id=id), color="black", fill="white", size=0.25)+
  geom_point(data = mapdata, aes(y=Lat_decimal, x=Long_decimal ), cex=0.5) +  
  coord_quickmap() +
  labs(x="Longitude", y="Latitude") +
  coord_equal(ratio=1)  + 
  scale_color_distiller(palette="BrBG", direction = -1) +
  theme(axis.text.x = element_blank(), axis.text.y = element_blank(),axis.ticks = element_blank(), legend.position = c(0.2, 0.8), panel.grid = element_blank())
map_PEFA

